@@ -1,14 +1,14 @@
 """
 Type annotations for route53-recovery-cluster service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_cluster/literals/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_cluster/literals/)
 
 Usage::
 
     ```python
-    from mypy_boto3_route53_recovery_cluster.literals import RoutingControlStateType
+    from mypy_boto3_route53_recovery_cluster.literals import ListRoutingControlsPaginatorName
 
-    data: RoutingControlStateType = "Off"
+    data: ListRoutingControlsPaginatorName = "list_routing_controls"
     ```
 """
 import sys
@@ -20,13 +20,16 @@ else:
 
 
 __all__ = (
+    "ListRoutingControlsPaginatorName",
     "RoutingControlStateType",
     "Route53RecoveryClusterServiceName",
     "ServiceName",
     "ResourceServiceName",
+    "PaginatorName",
 )
 
 
+ListRoutingControlsPaginatorName = Literal["list_routing_controls"]
 RoutingControlStateType = Literal["Off", "On"]
 Route53RecoveryClusterServiceName = Literal["route53-recovery-cluster"]
 ServiceName = Literal[
@@ -249,6 +252,7 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
     "proton",
@@ -345,3 +349,4 @@ ResourceServiceName = Literal[
     "sns",
     "sqs",
 ]
+PaginatorName = Literal["list_routing_controls"]
